<?php

namespace Drupal\migrate_html_to_paragraphs\Plugin\migrate\html\process;

use Drupal\migrate\MigrateExecutableInterface;
use Drupal\paragraphs\Entity\Paragraph;

/**
 * Migration HTML - text processor.
 *
 * @MigrateHtmlProcessPlugin(
 *   id = "html_process_text"
 * )
 */
class TextProcess extends HtmlTagProcess {

  /**
   * {@inheritdoc}
   */
  public function process(MigrateExecutableInterface $migrate_executable, array $tag) {
    $this->migrateExecutable = $migrate_executable;
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function createParagraph($value) {
    $text_format = 'full_html';

    // Cleanup HTML, ugly things which the text formats do not filter out.
    // Replace non breaking spaces to spaces.
    // ======================================
    // In order to be handled correctly in the next steps.
    $value = str_ireplace('&nbsp;', ' ', $value);

    // Remove commonly used occurrences.
    // =================================
    // E.g.:
    // - align="center"
    // - style="vertical-align: baseline;".
    $value = preg_replace('/(\s(align|style)=".*")/i', '', $value);

    // Remove all whitespace from empty HTML tags.
    // ===========================================
    // E.g.:
    // - <p> </p> becomes <p></p>.
    // - <div>          </div> becomes <div></div>.
    // - <iframe src="">           </iframe> becomes <iframe src=""></iframe>.
    $value = preg_replace('/<(.+)>\s*<\/(.+)>/i', '<$1></$2>', $value);

    // Remove commonly used HTML tags which are empty (useless).
    // =========================================================
    // E.g.:
    // - <p></p>
    // - <div></div>
    // - <strong></strong>.
    $html_tags = '(a|b|blockquote|div|em|h1|h2|h3|h4|h5|h6|label|li|ol|p|span|strong|ul)';
    $value = preg_replace('/<' . $html_tags . '>\s*<\/' . $html_tags . '>/i', '', $value);

    if (empty(check_markup($value, $text_format))) {
      return NULL;
    }

    $paragraph = Paragraph::create([
      'id' => NULL,
      'type' => 'text',
      'field_text' => [
        'value' => $value,
        'format' => $text_format,
      ],
    ]);
    $paragraph->save();

    return $paragraph;
  }

}
